==> icons-vue-0.3.0.tgz: package/es/brightness-contrast/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_BrightnessContrast20 = {
  name: 'BrightnessContrast20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 2H17V5H15zM27 15H30V17H27zM15 27H17V30H15zM2 15H5V17H2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M6.22 5.73H8.219999999999999V8.73H6.22z",
        "transform": "rotate(-45 7.227 7.236)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M23.27 6.23H26.27V8.23H23.27z",
        "transform": "rotate(-45 24.766 7.232)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M23.77 23.27H25.77V26.27H23.77z",
        "transform": "rotate(-45 24.77 24.77)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M5.47 25.13L7.59 23 9 24.42 6.88 26.54 5.47 25.13zM16 8a8 8 0 1 0 8 8A8 8 0 0 0 16 8zm0 14a6 6 0 0 1 0-12z"
      }
    }), children]);
  }
};

export default virtual_BrightnessContrast20;

==> icons-vue-0.6.0.tgz: package/es/brightness-contrast/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_BrightnessContrast20 = {
  name: 'BrightnessContrast20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "2"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "27",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "27"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "2",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "6.22",
        "y": "5.73",
        "transform": "rotate(-45 7.227 7.236)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "23.27",
        "y": "6.23",
        "transform": "rotate(-45 24.766 7.232)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "23.77",
        "y": "23.27",
        "transform": "rotate(-45 24.77 24.77)"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "5.47 25.13 7.59 23 9 24.42 6.88 26.54 5.47 25.13"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,8a8,8,0,1,0,8,8A8,8,0,0,0,16,8Zm0,14a6,6,0,0,1,0-12Z"
      }
    }), children]);
  }
};

export default virtual_BrightnessContrast20;
